@@ -6,14 +6,18 @@ import webbrowser
 import subprocess
 import platform
 import qdarkstyle
+import requests
 import math
-
+import base64
 import imgviz
+
 from qtpy import QtCore
 from qtpy.QtCore import Qt
 from qtpy import QtGui
 from qtpy import QtWidgets
 
+from itertools import zip_longest
+
 from enhancedlabelme import __appname__
 from enhancedlabelme import __version__
 from enhancedlabelme import PY2
@@ -381,9 +385,12 @@ class MainWindow(QtWidgets.QMainWindow):
         help = action(self.tr('&About'), self.about, icon='help',
                       tip=self.tr('About EnhancedLabelMe'))
         
-        readme = action(self.tr('&Readme'), self.readme, icon='icon',
+        readme = action(self.tr('&README'), self.readme, icon='icon',
                       tip=self.tr('Open README.md'))
         
+        update = action(self.tr('&Check Update'), self.checkUpdate, icon='update',
+                      tip=self.tr('Check available update'))
+        
         prefer = action(self.tr('&Preference'), self.preference, icon='edit',
                       tip=self.tr('Configure preference'))
 
@@ -586,7 +593,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 quit,
             ),
         )
-        utils.addActions(self.menus.help, (help, readme))
+        utils.addActions(self.menus.help, (help, readme, update))
         utils.addActions(
             self.menus.view,
             (
@@ -850,11 +857,11 @@ class MainWindow(QtWidgets.QMainWindow):
     def preference(self):
         try:
             if platform.system() == 'Darwin':       # macOS
-                subprocess.call(('open', os.path.join(os.path.expanduser('~'), 'lconfig')))
+                subprocess.call(('open', osp.join(osp.expanduser('~'), 'lconfig')))
             elif platform.system() == 'Windows':    # Windows
-                subprocess.call(('notepad.exe', os.path.join(os.path.expanduser('~'), 'lconfig')))
+                subprocess.call(('notepad.exe', osp.join(osp.expanduser('~'), 'lconfig')))
             else:                                   # linux variants
-                subprocess.call(('xdg-open', os.path.join(os.path.expanduser('~'), 'lconfig')))
+                subprocess.call(('xdg-open', osp.join(osp.expanduser('~'), 'lconfig')))
         except Exception:
             pass
 
@@ -870,6 +877,32 @@ class MainWindow(QtWidgets.QMainWindow):
             subprocess.call(('notepad.exe', 'README.md'))
         else:                                   # linux variants
             subprocess.call(('xdg-open', 'README.md'))
+            
+    def checkUpdate(self):
+        def compare(left, right):
+            left_vars = map(int, left.split('.'))
+            right_vars = map(int, right.split('.'))
+            for a, b in zip_longest(left_vars, right_vars, fillvalue = 0):
+                if a > b:
+                    return '>'
+                elif a < b:
+                    return '<'
+            return '='
+        
+        if osp.isfile('version.txt'):
+            os.remove('version.txt')
+        url= "https://raw.githubusercontent.com/LilactheGreat/versioncheck/master/version.txt"
+        os.system("curl " + url + " > version.txt")
+        with open("version.txt", 'r', encoding='utf-8') as f:
+            newversion = f.read()
+        if compare(newversion[0], __version__) == '>':
+            return QtWidgets.QMessageBox.about(
+                self, 'Checking Version', '\nCurrent Version : %s\nLatest Version : %s\n%s'%(
+                    __version__, str(newversion), 'Newer version is available'))
+        else:
+            return QtWidgets.QMessageBox.about(
+                self, 'Checking Version', '\nCurrent Version : %s\nLatest Version : %s\n%s'%(
+                    __version__, str(newversion), 'No available update'))
         
     def darkModeToggle(self):
         app = QtWidgets.QApplication.instance()
@@ -1860,6 +1893,16 @@ class MainWindow(QtWidgets.QMainWindow):
 
     def toggleKeepPrevMode(self):
         self._config['keep_prev'] = not self._config['keep_prev']
+        
+    def removeSelectedPoint(self):
+        shape = self.canvas.removeSelectedPoint()
+        if(shape.haveNoPoints()):
+            self.canvas.deleteShape(shape)
+            self.remLabels([shape])
+            self.setDirty()
+            if self.noShapes():
+                for action in self.actions.onShapesPresent:
+                    action.setEnabled(False)
 
     def deleteSelectedShape(self):
         yes, no = QtWidgets.QMessageBox.Yes, QtWidgets.QMessageBox.No
@@ -1982,10 +2025,12 @@ class MainWindow(QtWidgets.QMainWindow):
         self.openNextImg(load=load)
 
     def scanAllImages(self, folderPath):
-        extensions = ['.%s' % fmt.data().decode("ascii").lower()
-                      for fmt in QtGui.QImageReader.supportedImageFormats()]
-        images = []
+        extensions = [
+            ".%s" % fmt.data().decode().lower()
+            for fmt in QtGui.QImageReader.supportedImageFormats()
+        ]
 
+        images = []
         for root, dirs, files in os.walk(folderPath):
             for file in files:
                 if file.lower().endswith(tuple(extensions)):
